==> gnuradio-3.2.tar.gz: gnuradio-3.2/gr-qtgui/src/lib/qtgui_sink_f.h <==
/* -*- c++ -*- */
/*
 * Copyright 2008,2009 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_QTGUI_SINK_F_H
#define INCLUDED_QTGUI_SINK_F_H

#include <gr_block.h>
#include <gr_firdes.h>
#include <gri_fft.h>
#include <qapplication.h>
#include <qtgui.h>
#include <Python.h>
#include "SpectrumGUIClass.h"

class qtgui_sink_f;
typedef boost::shared_ptr<qtgui_sink_f> qtgui_sink_f_sptr;

qtgui_sink_f_sptr qtgui_make_sink_f (int fftsize, int wintype,
				     float fmin=-0.5, float fmax=0.5,
				     const std::string &name="Spectrum Display",
				     bool plotfreq=true, bool plotwaterfall=true,
				     bool plotwaterfall3d=true, bool plottime=true,
				     bool plotconst=true,
				     QWidget *parent=NULL);

class qtgui_sink_f : public gr_block
{
private:
  friend qtgui_sink_f_sptr qtgui_make_sink_f (int fftsize, int wintype,
					      float fmin, float fmax,
					      const std::string &name,
					      bool plotfreq, bool plotwaterfall,
					      bool plotwaterfall3d, bool plottime,
					      bool plotconst,
					      QWidget *parent);
  qtgui_sink_f (int fftsize, int wintype,
		float fmin, float fmax, 
		const std::string &name,
		bool plotfreq, bool plotwaterfall,
		bool plotwaterfall3d, bool plottime,
		bool plotconst,
		QWidget *parent);

  void initialize();

  int d_fftsize;
  gr_firdes::win_type d_wintype;
  std::vector<float> d_window;
  float d_fmin;
  float d_fmax;
  std::string d_name;
  
  pthread_mutex_t d_pmutex;

  bool d_shift;
  gri_fft_complex *d_fft;
  gr_complex *d_fftdata;

  int d_index;
  float *d_residbuf;

  bool d_plotfreq, d_plotwaterfall, d_plotwaterfall3d, d_plottime, d_plotconst;

  QWidget *d_parent;
  SpectrumGUIClass *d_main_gui; 

  void windowreset();
  void buildwindow();
  void fftresize();
  void fft(const float *data_in, int size, gr_complex *data_out);
  
public:
  ~qtgui_sink_f();
  void exec_();
  void lock();
  void unlock();
  QWidget*  qwidget();
  PyObject* pyqwidget();

  void set_frequency_range(const double centerfreq,
			   const double startfreq,
			   const double stopfreq);

  void set_time_domain_axis(double min, double max);
  void set_constellation_axis(double xmin, double xmax,
			      double ymin, double ymax);
  void set_frequency_axis(double min, double max);

  QApplication *d_qApplication;
  qtgui_obj *d_object;

  int general_work (int noutput_items,
		    gr_vector_int &ninput_items,
		    gr_vector_const_void_star &input_items,
		    gr_vector_void_star &output_items);
};

#endif /* INCLUDED_QTGUI_SINK_F_H */

==> gnuradio-3.2.1.tar.gz: gnuradio-3.2.1/gr-qtgui/src/lib/qtgui_sink_f.h <==
/* -*- c++ -*- */
/*
 * Copyright 2008,2009 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_QTGUI_SINK_F_H
#define INCLUDED_QTGUI_SINK_F_H

#include <gr_block.h>
#include <gr_firdes.h>
#include <gri_fft.h>
#include <qapplication.h>
#include <qtgui.h>
#include <Python.h>
#include "SpectrumGUIClass.h"

class qtgui_sink_f;
typedef boost::shared_ptr<qtgui_sink_f> qtgui_sink_f_sptr;

qtgui_sink_f_sptr qtgui_make_sink_f (int fftsize, int wintype,
				     double fc=0, double bw=1.0,
				     const std::string &name="Spectrum Display",
				     bool plotfreq=true, bool plotwaterfall=true,
				     bool plotwaterfall3d=true, bool plottime=true,
				     bool plotconst=true,
				     bool use_openGL=true,
				     QWidget *parent=NULL);

class qtgui_sink_f : public gr_block
{
private:
  friend qtgui_sink_f_sptr qtgui_make_sink_f (int fftsize, int wintype,
					      double fc, double bw,
					      const std::string &name,
					      bool plotfreq, bool plotwaterfall,
					      bool plotwaterfall3d, bool plottime,
					      bool plotconst,
					      bool use_openGL,
					      QWidget *parent);
  qtgui_sink_f (int fftsize, int wintype,
		double fc, double bw,
		const std::string &name,
		bool plotfreq, bool plotwaterfall,
		bool plotwaterfall3d, bool plottime,
		bool plotconst,
		bool use_openGL,
		QWidget *parent);

  void initialize(const bool opengl=true);

  int d_fftsize;
  gr_firdes::win_type d_wintype;
  std::vector<float> d_window;
  double d_center_freq;
  double d_bandwidth;
  std::string d_name;
  
  pthread_mutex_t d_pmutex;

  bool d_shift;
  gri_fft_complex *d_fft;
  gr_complex *d_fftdata;

  int d_index;
  float *d_residbuf;

  bool d_plotfreq, d_plotwaterfall, d_plotwaterfall3d, d_plottime, d_plotconst;

  QWidget *d_parent;
  SpectrumGUIClass *d_main_gui; 

  void windowreset();
  void buildwindow();
  void fftresize();
  void fft(const float *data_in, int size, gr_complex *data_out);
  
public:
  ~qtgui_sink_f();
  void exec_();
  void lock();
  void unlock();
  QWidget*  qwidget();
  PyObject* pyqwidget();

  void set_frequency_range(const double centerfreq,
			   const double bandwidth);

  void set_time_domain_axis(double min, double max);
  void set_constellation_axis(double xmin, double xmax,
			      double ymin, double ymax);
  void set_frequency_axis(double min, double max);

  QApplication *d_qApplication;
  qtgui_obj *d_object;

  int general_work (int noutput_items,
		    gr_vector_int &ninput_items,
		    gr_vector_const_void_star &input_items,
		    gr_vector_void_star &output_items);
};

#endif /* INCLUDED_QTGUI_SINK_F_H */
